

Project
===============
Easy access to the all the global envions like .env and os env

Installing
============

.. code-block:: bash

    pip install os-env

Usage
=====

.. code-block:: bash

    >>> import os-env
    >>> os-envs()
    '0.24.2'
